// -*-Mode: C++;-*- 

#ifndef CTextView_included
#define CTextView_included

#include "TextViewData.h"
#include <qtimer.h>
#include "kmysqladmin/helpers/smart_pointer.h"

class CMySql;

class CStatusView : public CTextViewData
{
    Q_OBJECT

public:
    CStatusView(smart_pointer<CMySql>& _sql_server,QWidget* parent = NULL,const char* name = NULL);
    virtual ~CStatusView();
    
protected:
    smart_pointer<CMySql> sql_server;
    QTimer*timer;
    int m_Timeout;
    void get_status();
    
protected slots:
    virtual void RefreshOutput();
    virtual void newTimeout(int aValue);
    virtual void clear(){};
    virtual void newFont();

public slots:
    void hide();
    void show();
};
#endif // CTextView_included
